@@ -1,8 +1,9 @@
 rforcecom.getObjectList <-
 function(session){
  # Load packages
- if(!require(XML)){ install.packages("XML"); stop(!require(XML)) }
- if(!require(RCurl)){ install.packages("RCurl"); stop(!require(RCurl)) }
+ #if(!require(XML)){ install.packages("XML"); stop(!require(XML)) }
+ #if(!require(RCurl)){ install.packages("RCurl"); stop(!require(RCurl)) }
+ #if(!require(plyr)){ install.packages("plyr"); stop(!require(plyr)) }
  
  # Send a query
  h <- basicHeaderGatherer()
