@@ -4,8 +4,9 @@ function(session, nextRecordsUrl){
  nextRecordsUrl <- sub("^/", "", nextRecordsUrl)
  
  # Load packages
- if(!require(XML)){ install.packages("XML"); stop(!require(XML)) }
- if(!require(RCurl)){ install.packages("RCurl"); stop(!require(RCurl)) }
+ #if(!require(XML)){ install.packages("XML"); stop(!require(XML)) }
+ #if(!require(RCurl)){ install.packages("RCurl"); stop(!require(RCurl)) }
+ #if(!require(plyr)){ install.packages("plyr"); stop(!require(plyr)) }
  
  # Retrieve XML via REST API
  h <- basicHeaderGatherer()
@@ -59,7 +60,7 @@ function(session, nextRecordsUrl){
  try(nextRecordsUrl <- iconv(xmlValue(x.root[['nextRecordsUrl']]), from="UTF-8", to=""), TRUE)
  if(!is.na(nextRecordsUrl)){
   nextRecords <- rforcecom.queryMore(session, nextRecordsUrl)
-  xdf.iconv <- rbind(xdf.iconv,nextRecords)
+  xdf.iconv <- rbind.fill(xdf.iconv,nextRecords)
  }
  
  return(data.frame(xdf.iconv))
