@@ -1,8 +1,9 @@
 rforcecom.search <-
 function(session, queryString){
  # Load packages
- if(!require(XML)){ install.packages("XML"); stop(!require(XML)) }
- if(!require(RCurl)){ install.packages("RCurl"); stop(!require(RCurl)) }
+ #if(!require(XML)){ install.packages("XML"); stop(!require(XML)) }
+ #if(!require(RCurl)){ install.packages("RCurl"); stop(!require(RCurl)) }
+ #if(!require(plyr)){ install.packages("plyr"); stop(!require(plyr)) }
  
  # Retrieve XML via REST API
  h <- basicHeaderGatherer()
